#!/bin/sh
# prepare parameters for ToI

. /lib/dracut-lib.sh
info "TuxOnIce premodule started"

# first check if ToI support is available
if [ ! -d /sys/power/tuxonice ]; then
  info "Kernel has no tuxonice support, aborting"
  return 0
else
  info "Kernel has tuxonice support, continuing"
fi

if getarg noresume2; then
  warn "noresume2 was specified, aborting"
  return 0
fi

# prepare UserUI
info "Setting up UserUI"
UI="/sbin/tuxoniceui_text"

if [ -e "/sys/class/graphics/fb0/state" -a -e "/sbin/tuxoniceui_fbsplash" -a -e "/etc/splash/tuxonice/" ]; then
  UI="/sbin/tuxoniceui_fbsplash"
fi

if [ -e "$UI" ]; then
  info "Using $UI"
  echo "$UI" >/sys/power/tuxonice/user_interface/program
  echo 1 >/sys/power/tuxonice/user_interface/enabled
else
  warn "$UI is not available"
  echo 0 >/sys/power/tuxonice/user_interface/enabled
fi

# prepare ToI signature
info "Preparing ToI signature"
if [ -f "/sys/power/tuxonice/binary_signature" ]; then
  dd if=/sys/power/tuxonice/binary_signature of=/.toisig count=1 bs=8 2>/dev/null
else
  echo -e "\xed\xc3\x02\xe9\x98\x56\xe5\x0c" > /.toisig
fi

# install udev rule for checking new block devices
info "Installing udev rule for ToI resume"
{
echo "SUBSYSTEM==\"block\", ACTION==\"add|change\", " \
     " RUN+=\"/sbin/tuxonice-resumecheck.sh '/dev/%k' '%E{ID_FS_TYPE}'\"";
} >> /etc/udev/rules.d/99-tuxonice.rules

